@@ -1,11 +1,13 @@
 lag2.plot <-
 function(series1, series2, max.lag=0, corr=TRUE, smooth=TRUE, col=gray(.1), bg=NA,
          lwl=1, lwc=2, bgl=NULL, ltcol=1, box.col=NULL, cex=.9, gg=FALSE, 
-         location="topright", ...){ 
+         location="topright", xname=NULL, yname=NULL, main=NULL, ...){ 
 #
-  name1  = paste(deparse(substitute(series1)),"(t-",sep="")
-  name10 = paste(deparse(substitute(series1)),"(t)",sep="")
-  name2  = paste(deparse(substitute(series2)),"(t)",sep="")
+  if (is.null(xname)) xname = deparse(substitute(series1))
+  if (is.null(yname)) yname = deparse(substitute(series2))
+  name1  = paste(xname,"(t-",sep="")
+  name10 = paste(xname,"(t)",sep="")
+  name2  = paste(yname,"(t)",sep="")
 #
   max.lag = as.integer(max.lag)
   m1      = max.lag + 1
@@ -23,7 +25,8 @@ function(series1, series2, max.lag=0, corr=TRUE, smooth=TRUE, col=gray(.1), bg=N
   series1 = as.ts(series1)
   series2 = as.ts(series2)
  par(mfrow = c(prow,pcol))
- if (par('cex') < .9) par(cex =.9)
+ if (par('cex') < .8) par(cex=.8)
+ if (!is.null(main)) par(oma=c(0,0,.75,0)+.1)
  for(h in 0:max.lag){       
    u = ts.intersect(lag(series1,-h), series2)   
    Xlab = ifelse(h==0, name10, paste(name1,h,")",sep="")) 
@@ -36,6 +39,7 @@ function(series1, series2, max.lag=0, corr=TRUE, smooth=TRUE, col=gray(.1), bg=N
            text.col=ltcol, bg=bgl, adj=.25, box.col=box.col, cex=.8)
   if (gg) { box(col=gray(1)) } else { box(col=gray(.62)) }
  }
+  if (!is.null(main))  title(main, outer=TRUE, line=-.10)
  on.exit(par(old.par))
 }
 }
